@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2009 Bill Wilson
+|  Copyright (C) 1999-2019 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -35,12 +35,17 @@
 
 #include "../src/gkrellm-sysdeps.h"
 
-#if defined(__linux__)
-#if defined(__GLIBC__) && ((__GLIBC__>2)||(__GLIBC__==2 && __GLIBC_MINOR__>=1))
+#if defined(WIN32)
+// Enable getaddrinfo on win32 if we target win xp or newer
+#if _WIN32_WINNT > 0x0500
 #define HAVE_GETADDRINFO	1
 #endif
 #endif
 
+#if defined(__linux__)
+#define HAVE_GETADDRINFO	1
+#endif
+
 #if defined(__DragonFly__)
 #define HAVE_GETADDRINFO	1
 #endif
