@@ -1,33 +1,51 @@
 /* GKrellM
-|  Copyright (C) 1999-2006 Bill Wilson
+|  Copyright (C) 1999-2019 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
+|
+|
+|  Additional permission under GNU GPL version 3 section 7
+|
+|  If you modify this program, or any covered work, by linking or
+|  combining it with the OpenSSL project's OpenSSL library (or a
+|  modified version of that library), containing parts covered by
+|  the terms of the OpenSSL or SSLeay licenses, you are granted
+|  additional permission to convey the resulting work.
+|  Corresponding Source for a non-source form of such a combination
+|  shall include the source code for the parts of OpenSSL used as well
+|  as that of the covered work.
 */
 
+
+#ifndef GKRELLM_H
+#define GKRELLM_H
+
 #if defined(HAVE_CONFIG_H)
 #include "config.h"
-#endif  
+#endif
+#include "log.h"
 
 #if !defined(WIN32)
 #include <sys/param.h>
 #endif
 
 #include <gtk/gtk.h>
+#include <glib/gstdio.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,7 +57,8 @@
 #if !defined(WIN32)
 #include <unistd.h>
 #else
-#include "win32.h"
+    #include <winsock2.h>
+    #include <process.h>
 #endif
 
 #include <sys/stat.h>
@@ -52,7 +71,7 @@
 
 #if !defined(__FreeBSD__) && !defined(__linux__) && !defined(__NetBSD__) \
 	&& !defined(__OpenBSD__) && !defined(__solaris__) && !defined(WIN32) \
-	&& !defined(__APPLE__)
+	&& !defined(__APPLE__) && !defined(__DragonFly__)
 #define  USE_LIBGTOP
 #endif
 
@@ -79,7 +98,7 @@
 #	define gettext(String) (String)
 #	define dgettext(Domain,String) (String)
 #	define dcgettext(Domain,String,Type) (String)
-#	define bindtextdomain(Domain,Directory) (Domain) 
+#	define bindtextdomain(Domain,Directory) (Domain)
 #endif	/* ENABLE_NLS */
 
 
@@ -88,9 +107,10 @@
 /* -------------------------------------------------------------------
 */
 #define	GKRELLM_VERSION_MAJOR	2
-#define	GKRELLM_VERSION_MINOR	2
-#define	GKRELLM_VERSION_REV		10
+#define	GKRELLM_VERSION_MINOR	3
+#define	GKRELLM_VERSION_REV		11
 #define	GKRELLM_EXTRAVERSION	""
+//#define	GKRELLM_EXTRAVERSION	"-pre1"
 
 #define GKRELLM_CHECK_VERSION(major,minor,rev)    \
 	(GKRELLM_VERSION_MAJOR > (major) || \
@@ -125,14 +145,10 @@
 
 #else
 
-#define     LOCAL_THEMES_DIR		"./themes"
-#if !defined(SYSTEM_THEMES_DIR)
-#define     SYSTEM_THEMES_DIR		"./themes"
-#endif
-#define     LOCAL_PLUGINS_DIR		"./plugins"
-#if !defined(SYSTEM_PLUGINS_DIR)
-#define     SYSTEM_PLUGINS_DIR		"./plugins"
-#endif
+#undef      LOCAL_THEMES_DIR
+#undef      SYSTEM_THEMES_DIR
+#undef      LOCAL_PLUGINS_DIR
+#undef      SYSTEM_PLUGINS_DIR
 
 #endif
 
@@ -140,7 +156,7 @@
 #define	ON				1
 #define	OFF				0
 
-#define	CFG_BUFSIZE		384
+#define	CFG_BUFSIZE		512
 
 
   /* Features
@@ -268,7 +284,7 @@ typedef struct
 	GdkBitmap	*stencil;
 	gint		y_src;		/* Offset into pixmap if a vertical stack	*/
 	gint		w, h;		/* Size of the decal						*/
-	gint		x, y;		/* Position of decal in a drawable			*/	
+	gint		x, y;		/* Position of decal in a drawable			*/
 	gshort		flags,
 				state;
 	gint		value;		/* Index into stack, text value, etc	*/
@@ -491,6 +507,7 @@ typedef struct
 	gint		h_configure;
 
 	PangoLayout	*layout;
+	PangoLayout	 *label_layout;
 
 	gint		transparency;
 	gboolean	modified;		/* True if decal/krell modified.	*/
@@ -553,7 +570,7 @@ typedef struct
 	gpointer	cb_grid_resolution_data;
 	GtkWidget	*grid_resolution_spin_button;
 	GtkWidget	*auto_resolution_control_menubar;
-	GtkItemFactory	*auto_resolution_item_factory;
+	GtkUIManager	*auto_resolution_ui_manager;
 	gchar		*grid_resolution_label;
 	gboolean	adjustment_is_set;
 	gboolean	map_sequence;
@@ -706,11 +723,12 @@ typedef struct
 	gchar		*label;
 	gulong		current,
 				previous,
+				wrap,
 				discard;
 	gboolean	monotonic;
 	GkrellmChartlayer layer;	/* The image + grid for this data layer */
 	GdkBitmap	*data_bitmap;	/* Draw data here, use as clipmask for layer*/
-	gint		*data;
+	gulong		*data;
 
 	gint		draw_style;
 	gboolean	inverted;
@@ -727,7 +745,7 @@ typedef struct
 	gint		y,				/* Each data layer draws at an offset y and */
 				h,				/* within height h of its parent GkrellmChart*/
 				w;				/* Width of data allocated.				*/
-	gint		maxval;
+	gulong		maxval;
 	}
 	GkrellmChartdata;
 
@@ -760,7 +778,7 @@ typedef struct
 	gint		pad;
 	FILE		*pipe;		/* Read the output of some commands */
 	GkrellmDecalbutton	*button;
-	GtkTooltips	*tooltip;
+        void *tooltip_filler;
 	gchar		*tooltip_comment;
 	GkrellmDecal *decal;		/* Used if DECAL_LAUNCHER type	*/
 	GkrellmMargin margin;
@@ -1049,19 +1067,20 @@ typedef struct _GkrellmMonitor
 	void		(*save_user_config)(FILE *);
 	void		(*load_user_config)(gchar *);
 	gchar		*config_keyword;
-	
+
 	void		(*undef2)(void);
 	void		(*undef1)(void);
 	GkrellmMonprivate *privat;
 
 	gint		insert_before_id;		/* If plugin, insert before this mon*/
-	
+
 	void		*handle;				/* If monitor is a plugin.	*/
 	gchar		*path;					/* 	"						*/
 	}
 	GkrellmMonitor;
 
-extern GList	*gkrellm_monitor_list;
-
 
 #include "gkrellm-public-proto.h"
+
+#endif // GKRELLM_H
+
