@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
+|  Copyright (C) 1999-2019 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -224,10 +224,13 @@ read_sensors_thread(void *data)
 static void
 run_sensors_thread(void)
 	{
+	GThread		*gth;
+
 	if (thread_busy)
 		return;
 	thread_busy = TRUE;
-	g_thread_create(read_sensors_thread, NULL, FALSE, NULL);
+	gth = g_thread_new("read_sensors", read_sensors_thread, NULL);
+	g_thread_unref(gth);
 	}
 
   /* Sort so that sensors are ordered: temp, fan, voltage.
@@ -705,22 +708,28 @@ static gint		pixel_grub;
 static gfloat		sensor_float_factor = 1.0,
 					gkrellm_float_factor = 1.0;
 
-void
+gboolean
 gkrellm_sensor_reset_location(gpointer sr)
 	{
-	GList	*list;
-	Sensor	*sensor;
+	GList		*list;
+	Sensor		*sensor;
+	gboolean	result = FALSE;
 
-	for (list = sensor_list; list; list = list->next)
+	if (sr)
 		{
-		sensor = (Sensor *) list->data;
-		if (sr == sensor)
+		for (list = sensor_list; list; list = list->next)
 			{
-			sensor->location = SENSOR_PANEL_LOCATION;
-			sensor_reset_optionmenu(sensor);
-			break;
+			sensor = (Sensor *) list->data;
+			if (sr == sensor)
+				{
+				sensor->location = SENSOR_PANEL_LOCATION;
+				sensor_reset_optionmenu(sensor);
+				result = TRUE;
+				break;
+				}
 			}
 		}
+	return result;
 	}
 
 
@@ -1660,7 +1669,7 @@ gkrellm_init_sensor_monitor(void)
   |  to composite CPU on a SMP machine.
   |
   |  2.1.15 scales sensor factor/offset values by SENSOR_FLOAT_FACTOR to avoid
-  |  writting decimal points in the config.  This is not backwards compatible
+  |  writing decimal points in the config.  This is not backwards compatible
   |  with the pre 2.1.15 sensor_config format hence the config file name
   |  change to sensor-config.  But sensor_config is forward compatible
   |  since the float factor defaults to 1.0.
@@ -1964,8 +1973,7 @@ static GtkTreeRowReference	*row_reference;
 static GtkTreeSelection		*selection;
 
 
-static GtkWidget	*optionmenu,
-					*optionmenu_menu;
+static GtkWidget	*optionmenu;
 
 static GtkWidget	*display_mode_button[2];
 static GtkWidget	*factor_spin_button,
@@ -2267,19 +2275,19 @@ sensor_reset_optionmenu(Sensor *sensor)
 		return;
 	sr = get_referenced_sensor();
 	if (sr == sensor)
-		gtk_option_menu_set_history(GTK_OPTION_MENU(optionmenu),
+		gtk_combo_box_set_active(GTK_COMBO_BOX(optionmenu),
 					SENSOR_PANEL_LOCATION);
 	}
 
 static void
-cb_location_menu(GtkOptionMenu *om, gpointer data)
+cb_location_menu(GtkComboBox *om, gpointer data)
 	{
 	GList		*list;
 	Sensor		*sr, *s;
 	gchar		*pname = NULL;
 	gint		location;
 
-	location = gtk_option_menu_get_history(om);
+	location = gtk_combo_box_get_active(om);
 	sr = get_referenced_sensor();
 	if (!sr || !sr->enabled || sr->location == location)
 		return;
@@ -2323,7 +2331,7 @@ cb_location_menu(GtkOptionMenu *om, gpointer data)
 
 	if (sr->location != location)	/* location failed */
 		{
-		gtk_option_menu_set_history(GTK_OPTION_MENU(optionmenu),
+		gtk_combo_box_set_active(GTK_COMBO_BOX(optionmenu),
 					SENSOR_PANEL_LOCATION);
 		sensor_relocation_error(pname);
 		}
@@ -2333,52 +2341,34 @@ cb_location_menu(GtkOptionMenu *om, gpointer data)
 static void
 create_location_menu(gint group)
 	{
-	GtkWidget	*menu;
-	GtkWidget	*menuitem;
+	gchar		*label;
 	gint		n, n_cpus;
-	static gint	sig_id;
 
 	if (group == sensor_last_group)
 		return;
 	sensor_last_group = group;
 
-	if (optionmenu_menu)
-		{
-		g_signal_handler_disconnect(G_OBJECT(optionmenu), sig_id);
-		gtk_widget_destroy(optionmenu_menu);
-		}
-
-	menu = gtk_menu_new();
-
-	menuitem = gtk_menu_item_new_with_label("default");
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
-	gtk_widget_show(menuitem);
+	gtk_combo_box_append_text(GTK_COMBO_BOX(optionmenu), "default");
 
 	if (group == SENSOR_GROUP_MAINBOARD)
 		{
-		menuitem = gtk_menu_item_new_with_label(
-					gkrellm_proc_get_sensor_panel_label());
-		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
-		gtk_widget_show(menuitem);
+		label = gkrellm_proc_get_sensor_panel_label();
+		if (label)
+			gtk_combo_box_append_text(GTK_COMBO_BOX(optionmenu), label);
 
 		n_cpus = gkrellm_smp_cpus() + 1;
 		for (n = 0; n < n_cpus; ++n)
 			{
-			menuitem = gtk_menu_item_new_with_label(
-						gkrellm_cpu_get_sensor_panel_label(n));
-			gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
-			gtk_widget_show(menuitem);
+			label = gkrellm_cpu_get_sensor_panel_label(n);
+			if (label)
+				gtk_combo_box_append_text(GTK_COMBO_BOX(optionmenu), label);
 			}
 		}
 	else if (group == SENSOR_GROUP_DISK)
 		{
-		menuitem = gtk_menu_item_new_with_label(_("Disk"));
-		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
-		gtk_widget_show(menuitem);
+		gtk_combo_box_append_text(GTK_COMBO_BOX(optionmenu), _("Disk"));
 		}
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(optionmenu), menu);
-	optionmenu_menu = menu;
-	sig_id = g_signal_connect(G_OBJECT(optionmenu), "changed",
+	g_signal_connect(G_OBJECT(optionmenu), "changed",
 				G_CALLBACK(cb_location_menu), NULL);
 	}
 
@@ -2408,7 +2398,7 @@ set_sensor_widget_states(Sensor *s)
 			}
 		}
 	create_location_menu(s ? s->group : 0);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(optionmenu), location);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(optionmenu), location);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(factor_spin_button), factor);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(offset_spin_button), offset);
 	gtk_widget_set_sensitive(optionmenu, p_sensitive);
@@ -2458,7 +2448,7 @@ cb_tree_selection_changed(GtkTreeSelection *selection, gpointer data)
 	GtkTreeModel	*model;
 	GtkTreePath		*path;
 	Sensor			*s;
-	gint            *indices, depth;
+	gint            depth;
 
 	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
 		{
@@ -2467,11 +2457,7 @@ cb_tree_selection_changed(GtkTreeSelection *selection, gpointer data)
 		return;
 		}
 	path = gtk_tree_model_get_path(model, &iter);
-	indices = gtk_tree_path_get_indices(path);
 	depth = gtk_tree_path_get_depth(path);
-//g_debug("selection: indices=[%d,%d]:%d, path=%s\n",
-//		indices[0], indices[1], gtk_tree_path_get_depth(path),
-//		gtk_tree_path_to_string(path));
     change_row_reference(model, path);
     gtk_tree_path_free(path);
 
@@ -2695,6 +2681,10 @@ N_("Drag and drop sensor rows to change the displayed order.\n"),
 "\n",
 N_("Temperature offset values must be in centigrade units.\n"),
 "\n",
+N_("If you use Pango markup for any custom labels, do not use double quotes.\n"),
+N_("For example, to set a colored CPU label, use single quotes:\n"),
+N_("    <span foreground='cyan'>CPU</span>\n"),
+"\n",
 N_("Substitution variables may be used in alert commands.\n"),
 N_("\t$s    current sensor value.\n"),
 N_("\t$l    sensor label.\n"),
@@ -2809,8 +2799,7 @@ create_sensors_tab(GtkWidget *tab_vbox)
 
 	box = gkrellm_gtk_framed_vbox(vbox1, _("Location"), 2, FALSE, 0, 2);
 
-	optionmenu = gtk_option_menu_new();
-	optionmenu_menu = NULL;
+	optionmenu = gtk_combo_box_new_text();
 
 	gtk_box_pack_start(GTK_BOX(box), optionmenu, FALSE, FALSE, 4);
 
